aboutsummaryrefslogtreecommitdiffstats
path: root/youtube/watch.py
diff options
context:
space:
mode:
Diffstat (limited to 'youtube/watch.py')
-rw-r--r--youtube/watch.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/youtube/watch.py b/youtube/watch.py
index 8ef9448..11ef9f2 100644
--- a/youtube/watch.py
+++ b/youtube/watch.py
@@ -226,9 +226,9 @@ def extract_info(video_id, use_invidious, playlist_id=None, index=None):
return {'error': 'Failed to parse json response'}
info = yt_data_extract.extract_watch_info(polymer_json)
# request player if it's missing
# see https://github.com/user234683/youtube-local/issues/22#issuecomment-706395160
- if info['age_restricted'] or info['player_response_missing']:
+ if info['age_restricted'] or info['player_urls_missing']:
if info['age_restricted']:
print('Age restricted video. Fetching get_video_info page')
else:
@@ -226,9 +226,9 @@ def extract_info(video_id, use_invidious, playlist_id=None, index=None):
return {'error': 'Failed to parse json response'}
info = yt_data_extract.extract_watch_info(polymer_json)
- # request player if it's missing
+ # request player urls if it's missing
# see https://github.com/user234683/youtube-local/issues/22#issuecomment-706395160